from base64 import b64encode, b64decode
from urllib import parse


def url_encode(content: str):
    result = parse.quote(content)
    return result


def url_decode(content: str):
    result = parse.unquote(content)
    return result


def base64_encode(content: str):
    st = content.encode()  # 默认以utf8编码
    result = b64encode(st)
    return result.decode()


def base64_decode(content: str):
    st = content.encode()  # 默认以utf8编码
    result = b64decode(st)
    return result.decode()



from lencode import *

if __name__ == '__main__':
    content = '你好，世界'
    result = url_encode(content)
    print(result)
    result = url_decode(result)
    print(result)
    print(base64_encode('你好，世界'))
    print(base64_decode('5L2g5aW977yM5LiW55WM'))



import setuptools

with open('README.md', 'r', encoding='u8') as fh:
    long_description = fh.read()

setuptools.setup(
    name='lencode',
    version='0.1.1',
    author='linupy',
    author_email='linupy@163.com',
    description='编码/加密工具包 Encoding/Encryption Toolkit',
    url='https://github.com/linupychiang/lencode',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=setuptools.find_packages(),

    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],

    install_requires=[],
    python_requires='>=3',
)
